pub fn generate_parser(grammar: &Grammar) -> Result<String, Error>
Generate a String of Rust source implememting parsers for the given grammar.
If the prettyplease feature is enabled, the returned code will be pretty-printed.
prettyplease